# History

## 0.3.1

* add a display_name attribute by @chrishavlin in [62](https://github.com/yt-project/yt_idv/pull/62)
* preprocessor directives by @matthewturk in [70](https://github.com/yt-project/yt_idv/pull/70)
* Set unitary scale for the block collection by @matthewturk in [79](https://github.com/yt-project/yt_idv/pull/79)
* ds_tex objects by @matthewturk in [47](https://github.com/yt-project/yt_idv/pull/47)
* isocontour improvements by @chrishavlin in [43](https://github.com/yt-project/yt_idv/pull/43)
* installation note for wayland on linux by @chrishavlin in [82](https://github.com/yt-project/yt_idv/pull/82)
* updates to documentation by @chrishavlin in [85](https://github.com/yt-project/yt_idv/pull/85)

**Full Changelog**: https://github.com/yt-project/yt_idv/compare/v0.3.0...v0.3.1

## 0.3.0

* minimum yt version is now 4.1
* Added isocontour shader by @sochowski in [40](https://github.com/yt-project/yt_idv/pull/40)
* Block-rendering based slicing by @matthewturk in [13](https://github.com/yt-project/yt_idv/pull/13)
* Curve plotting by @chrishavlin in [26](https://github.com/yt-project/yt_idv/pull/26)
* Pop-up help by @chrishavlin in [44](https://github.com/yt-project/yt_idv/pull/44)
* allow uniform arrays by @matthewturk in [38](https://github.com/yt-project/yt_idv/pull/38)
* Make windows resizable by @matthewturk in [57](https://github.com/yt-project/yt_idv/pull/57)

**Full Changelog**: [v0.2.3-v0.3.0](https://github.com/yt-project/yt_idv/compare/v0.2.3...v0.3.0)

## 0.2.3
* Fixes to manifest, restoring pypi functionality.

## 0.2.2
* bug fixes and improvements: full change history to come in upcoming minor release.

## 0.2.0

* Add grid positions annotation
* Add OSMesa rendering context for off-screen rendering
* Add geometry shader support
* Add tests and a handful of new examples
* Fix rendering meshes
* Regularize uniform names across shaders

## 0.1.0

* First release on PyPI.
